==> galileo-1.11.0-py3-none-any.whl: galileo/resources/api/trace/update_trace_projects_project_id_traces_trace_id_patch.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.log_trace_update_request import LogTraceUpdateRequest
from ...models.log_trace_update_response import LogTraceUpdateResponse
from ...types import Response


def _get_kwargs(project_id: str, trace_id: str, *, body: LogTraceUpdateRequest) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {"method": "patch", "url": f"/projects/{project_id}/traces/{trace_id}"}

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    if response.status_code == 200:
        response_200 = LogTraceUpdateResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, trace_id: str, *, client: AuthenticatedClient, body: LogTraceUpdateRequest
) -> Response[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogTraceUpdateResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id, body=body)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, trace_id: str, *, client: AuthenticatedClient, body: LogTraceUpdateRequest
) -> Optional[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogTraceUpdateResponse]
    """

    return sync_detailed(project_id=project_id, trace_id=trace_id, client=client, body=body).parsed


async def asyncio_detailed(
    project_id: str, trace_id: str, *, client: AuthenticatedClient, body: LogTraceUpdateRequest
) -> Response[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogTraceUpdateResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id, body=body)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, trace_id: str, *, client: AuthenticatedClient, body: LogTraceUpdateRequest
) -> Optional[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogTraceUpdateResponse]
    """

    return (await asyncio_detailed(project_id=project_id, trace_id=trace_id, client=client, body=body)).parsed

==> galileo-1.16.2-py3-none-any.whl: galileo/resources/api/trace/update_trace_projects_project_id_traces_trace_id_patch.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.log_trace_update_request import LogTraceUpdateRequest
from ...models.log_trace_update_response import LogTraceUpdateResponse
from ...types import Response


def _get_kwargs(project_id: str, trace_id: str, *, body: LogTraceUpdateRequest) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.PATCH,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/traces/{trace_id}",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    if response.status_code == 200:
        response_200 = LogTraceUpdateResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, trace_id: str, *, client: ApiClient, body: LogTraceUpdateRequest
) -> Response[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogTraceUpdateResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id, body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, trace_id: str, *, client: ApiClient, body: LogTraceUpdateRequest
) -> Optional[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogTraceUpdateResponse]
    """

    return sync_detailed(project_id=project_id, trace_id=trace_id, client=client, body=body).parsed


async def asyncio_detailed(
    project_id: str, trace_id: str, *, client: ApiClient, body: LogTraceUpdateRequest
) -> Response[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogTraceUpdateResponse]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id, body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, trace_id: str, *, client: ApiClient, body: LogTraceUpdateRequest
) -> Optional[Union[HTTPValidationError, LogTraceUpdateResponse]]:
    """Update Trace

     Update a trace with the given ID.

    Args:
        project_id (str):
        trace_id (str):
        body (LogTraceUpdateRequest): Request model for updating a trace.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, LogTraceUpdateResponse]
    """

    return (await asyncio_detailed(project_id=project_id, trace_id=trace_id, client=client, body=body)).parsed
